@@ -24,6 +24,7 @@
 #include "src/svnqt/revision.hpp"
 #include "src/svnqt/smart_pointer.hpp"
 #include "src/svnqt/shared_pointer.hpp"
+#include "src/svnqt/svnqttypes.hpp"
 
 #include "simple_logcb.h"
 
@@ -44,6 +45,7 @@ class KProcess;
 class SvnActionsData;
 class CheckModifiedThread;
 class CheckUpdatesThread;
+class FillCacheThread;
 
 namespace svn {
     class Context;
@@ -62,6 +64,12 @@ class SvnActions : public QObject,public SimpleLogCb
 {
     Q_OBJECT
 public:
+    enum ThreadType {
+        checkupdatethread,
+        fillcachethread,
+        checkmodifiedthread
+    };
+
     SvnActions(ItemDisplay *parent, const char *name = 0,bool processes_blocked=false);
     ~SvnActions();
     void reInitClient();
@@ -72,17 +80,17 @@ public:
             const char*name="standard_dialog",
             bool showHelp=false,bool modal=true,
             const KGuiItem&u1 = KGuiItem());
-    QByteArray makeGet(const svn::Revision&start, const QString&what,
-        const svn::Revision&peg=svn::Revision::UNDEFINED,QWidget*dlgparent=0);
+
     bool makeGet(const svn::Revision&start, const QString&what,const QString&target,
         const svn::Revision&peg=svn::Revision::UNDEFINED,QWidget*dlgparent=0);
 
-    bool addItems(const QValueList<svn::Path> &items,bool rec=false);
-    bool addItems(const QStringList&w,bool rec=false);
+
+    bool addItems(const QValueList<svn::Path> &items,svn::Depth depth=svn::DepthEmpty);
+    bool addItems(const QStringList&w,svn::Depth depth=svn::DepthEmpty);
     void checkAddItems(const QString&path,bool print_error_box=true);
 
-    void makeDelete(const QValueList<svn::Path>&);
-    void makeDelete(const QStringList&);
+    bool makeDelete(const svn::Pathes&);
+    bool makeDelete(const QStringList&);
     void makeLock(const QStringList&,const QString&,bool);
     void makeUnlock(const QStringList&,bool);
 
@@ -91,16 +99,19 @@ public:
     bool makeList(const QString&url,svn::DirEntries&dlist,svn::Revision&where,bool rec=false);
 
     bool createModifiedCache(const QString&base);
-    void getModifiedCache(const QString&path,svn::StatusEntries&dlist);
     bool checkModifiedCache(const QString&path);
     bool checkConflictedCache(const QString&path);
     bool checkReposLockCache(const QString&path);
-    bool checkReposLockCache(const QString&path,svn::Status&t);
-    void addModifiedCache(const svn::Status&what);
+    bool checkReposLockCache(const QString&path,svn::SharedPointer<svn::Status>&t);
+    void addModifiedCache(const svn::StatusPtr&what);
     void deleteFromModifiedCache(const QString&what);
 
     bool makeIgnoreEntry(SvnItem*which,bool unignore);
     bool isLockNeeded(SvnItem*which,const svn::Revision&where);
+    QString searchProperty(QString&store, const QString&property, const QString&start,const svn::Revision&where,bool up=false);
+    svn::PathPropertiesMapListPtr propList(const QString&which,const svn::Revision&where,bool cacheOnly);
+
+    bool changeProperties(const svn::PropertiesMap&setList,const QValueList<QString>&,const QString&path);
 
     //! generate and displays a revision tree
     /*!
@@ -114,18 +125,18 @@ public:
     void makeTree(const QString&what,const svn::Revision&rev,
         const svn::Revision&startr=svn::Revision(1),
         const svn::Revision&endr=svn::Revision::HEAD);
-    void makeLog(const svn::Revision&start,const svn::Revision&end,SvnItem*k,bool list_files=false,int limit = 0);
-    void makeLog(const svn::Revision&start,const svn::Revision&end,const QString&,bool list_files=false, int limit=0);
-    svn::SharedPointer<svn::LogEntriesMap> getLog(const svn::Revision&start,const svn::Revision& end,const QString&,bool list_files, int limit);
+    void makeLog(const svn::Revision&start,const svn::Revision&end,const svn::Revision&peg,SvnItem*k,bool list_files=false,int limit = 0);
+    void makeLog(const svn::Revision&start,const svn::Revision&end,const svn::Revision&peg,const QString&,bool list_files=false, int limit=0);
+    svn::SharedPointer<svn::LogEntriesMap> getLog(const svn::Revision&start,const svn::Revision& end,const svn::Revision&peg,const QString&,bool list_files, int limit,QWidget*parent=0);
     virtual bool getSingleLog(svn::LogEntry&,const svn::Revision&,const QString&,const svn::Revision&,QString&root);
 
     void makeBlame(const svn::Revision&start, const svn::Revision&end, SvnItem*k);
     void makeBlame(const svn::Revision&start, const svn::Revision&end, const QString&,QWidget*parent=0,const svn::Revision&peg=svn::Revision::UNDEFINED,SimpleLogCb*_acb=0);
     void makeUpdate(const QStringList&what,const svn::Revision&rev,bool recurse);
-    bool makeSwitch(const QString&rUrl,const QString&tPath,const svn::Revision&r,bool rec = true);
+    bool makeSwitch(const QString&rUrl,const QString&tPath,const svn::Revision&r,svn::Depth depth,const svn::Revision&peg,bool stickydepth,bool ignore_externals,bool allow_unversioned);
     bool makeSwitch(const QString&path,const QString&what);
     bool makeRelocate(const QString&fUrl,const QString&tUrl,const QString&path,bool rec = true);
-    bool makeCheckout(const QString&,const QString&,const svn::Revision&,bool,bool,bool,bool,bool exp_rec=true, QWidget*p=0);
+    bool makeCheckout(const QString&,const QString&,const svn::Revision&,const svn::Revision&,svn::Depth,bool isExport,bool openit,bool ignore_externals,bool overwrite,QWidget*p);
     void makeInfo(QPtrList<SvnItem> lst,const svn::Revision&,const svn::Revision&,bool recursive = true);
     void makeInfo(const QStringList&lst,const svn::Revision&,const svn::Revision&,bool recursive = true);
     bool makeCommit(const svn::Targets&);
@@ -140,11 +151,14 @@ public:
     bool createUpdateCache(const QString&what);
     bool checkUpdateCache(const QString&path)const;
     bool isUpdated(const QString&path)const;
-    bool getUpdated(const QString&path,svn::Status&d)const;
+    bool getUpdated(const QString&path,svn::SharedPointer<svn::Status>&d)const;
     void clearUpdateCache();
     void removeFromUpdateCache(const QStringList&what,bool exact_only);
     void stopCheckModThread();
     void stopCheckUpdateThread();
+    void startFillCache(const QString&path);
+    void stopFillCache();
+    void stopMain();
     void killallThreads();
 
     bool checkUpdatesRunning();
@@ -159,7 +173,17 @@ public:
     virtual bool makeCleanup(const QString&);
 
     bool get(const QString&what,const QString& to,const svn::Revision&rev,const svn::Revision&peg,QWidget*p);
-    bool singleInfo(const QString&what,const svn::Revision&rev,svn::InfoEntry&target);
+    bool singleInfo(const QString&what,const svn::Revision&rev,svn::InfoEntry&target,const svn::Revision&_peg=svn::Revision::UNDEFINED);
+
+    void setContextData(const QString&,const QString&);
+    void clearContextData();
+    QString getContextData(const QString&)const;
+
+    bool threadRunning(ThreadType which);
+
+    virtual void customEvent ( QCustomEvent * e );
+
+    bool doNetworking();
 
 protected:
     svn::smart_pointer<SvnActionsData> m_Data;
@@ -168,8 +192,9 @@ protected:
     void CheckoutExportCurrent(bool _exp);
     void makeAdd(bool rec);
     CheckModifiedThread*m_CThread,*m_UThread;
-    void makeDiffinternal(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*);
-    void makeDiffExternal(const QString&p1,const svn::Revision&start,const QString&p2,const svn::Revision&end,bool isDir,QWidget*p,bool rec=true);
+    FillCacheThread*m_FCThread;
+    void makeDiffinternal(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*,const svn::Revision&peg=svn::Revision::UNDEFINED);
+    void makeDiffExternal(const QString&p1,const svn::Revision&start,const QString&p2,const svn::Revision&end,const svn::Revision&_peg,bool isDir,QWidget*p,bool rec=true);
 
 public slots:
     virtual void dispDiff(const QByteArray&);
@@ -188,28 +213,33 @@ public slots:
     virtual void slotRevertItems(const QStringList&);
     virtual void slotSwitch();
     virtual void slotResolved(const QString&);
-    virtual void makeDiff(const QString&,const svn::Revision&,const svn::Revision&,bool isDir);
+    virtual void slotResolve(const QString&);
+    virtual void makeDiff(const QString&,const svn::Revision&,const svn::Revision&,const svn::Revision&_peg,bool isDir);
     virtual void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&);
-    virtual void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,bool,QWidget*p);
+    virtual void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,const svn::Revision&,bool,QWidget*p);
     virtual void makeDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*);
     virtual void makeNorecDiff(const QString&,const svn::Revision&,const QString&,const svn::Revision&,QWidget*);
-    virtual void slotImport(const QString&,const QString&,const QString&,bool);
+    virtual void slotImport(const QString&,const QString&,const QString&,svn::Depth,bool noIgnore,bool noUnknown);
     virtual void slotMergeWcRevisions(const QString&,const svn::Revision&,const svn::Revision&,bool,bool,bool,bool);
     virtual void slotMerge(const QString&,const QString&, const QString&,
         const svn::Revision&,const svn::Revision&,bool,bool,bool,bool);
-    void slotMergeExternal(const QString&src1,const QString&src2, const QString&target,const svn::Revision&rev1,const svn::Revision&rev2,bool);
+    virtual void slotMergeExternal(const QString&src1,const QString&src2, const QString&target,const svn::Revision&rev1,const svn::Revision&rev2,bool);
     virtual void slotExtraLogMsg(const QString&);
-    void slotMakeCat(const svn::Revision&start, const QString&what,const QString&disp,const svn::Revision&peg,QWidget*dlgparent);
+    virtual void slotMakeCat(const svn::Revision&start, const QString&what,const QString&disp,const svn::Revision&peg,QWidget*dlgparent);
+
+    virtual void slotCancel(bool);
 
 signals:
     void clientException(const QString&);
     void sendNotify(const QString&);
     void reinitItem(SvnItem*);
     void sigRefreshAll();
+    void sigThreadsChanged();
     void sigRefreshCurrent(SvnItem*);
     void sigRefreshIcons(bool);
     void sigExtraLogMsg(const QString&);
     void sigGotourl(const QString&);
+    void sigCacheStatus(Q_LONG,Q_LONG);
 
 protected slots:
     virtual void wroteStdin(KProcess*);
