@@ -1,3 +1,8 @@
+/*
+ * Port for usage with qt-framework and development for kdesvn
+ * (C) 2005-2007 by Rajko Albrecht
+ * http://kdesvn.alwins-world.de
+ */
 /*
  * ====================================================================
  * Copyright (c) 2002-2005 The RapidSvn Group.  All rights reserved.
@@ -31,12 +36,14 @@
 #pragma warning (disable: 4786)
 #endif
 
-// Ignore MSVC 7 compiler warning: C++ exception specification
-#if defined (_MSC_VER) && _MSC_VER > 1200 && _MSC_VER <= 1310
+// Ignore MSVC 7, 2005 & 2008 compiler warning: C++ exception specification
+#if defined (_MSC_VER) && _MSC_VER > 1200 && _MSC_VER <= 1550
 #pragma warning (disable: 4290)
 #endif
 
-#include "svnqt_defines.hpp"
+#include "svnqt/svnqt_defines.hpp"
+#include "svnqt/svnqttypes.hpp"
+#include "svnqt/svnstream.hpp"
 
 // qt
 #include <qglobal.h>
@@ -50,62 +57,32 @@
     #include <QtCore>
 #endif
 
-// svncpp
-#include "context.hpp"
-#include "exception.hpp"
-#include "path.hpp"
-#include "entry.hpp"
-#include "revision.hpp"
-#include "log_entry.hpp"
-#include "info_entry.hpp"
-#include "annotate_line.hpp"
+// svnqt
+#include "svnqt/context.hpp"
+#include "svnqt/exception.hpp"
+#include "svnqt/path.hpp"
+#include "svnqt/entry.hpp"
+#include "svnqt/revision.hpp"
+#include "svnqt/log_entry.hpp"
+#include "svnqt/info_entry.hpp"
+#include "svnqt/annotate_line.hpp"
+#include "svnqt/stringarray.hpp"
+#include "svnqt/diffoptions.hpp"
+#include "svnqt/conflictresult.hpp"
 
+class QStringList;
 
 namespace svn
 {
-  // forward declarations
-  class Context;
-  class Status;
-  class Targets;
-  class DirEntry;
-
-#if QT_VERSION < 0x040000
-  typedef QValueList<LogEntry> LogEntries;
-  typedef QValueList<InfoEntry> InfoEntries;
-  typedef QValueList<Status> StatusEntries;
-  typedef QValueList<DirEntry> DirEntries;
-  typedef QValueList<AnnotateLine> AnnotatedFile;
-  typedef QValueList<Revision> Revisions;
-#else
-  typedef QList<LogEntry> LogEntries;
-  typedef QList<InfoEntry> InfoEntries;
-  typedef QList<Status> StatusEntries;
-  typedef QList<DirEntry> DirEntries;
-  typedef QList<AnnotateLine> AnnotatedFile;
-  typedef QList<Revision> Revisions;
-#endif
-
-  // map of logentries - key is revision
-  typedef QMap<long,LogEntry> LogEntriesMap;
-  // map of property names to values
-  typedef QMap<QString,QString> PropertiesMap;
-  // pair of path, PropertiesMap
-  typedef QPair<QString, PropertiesMap> PathPropertiesMapEntry;
-  // vector of path, Properties pairs
-#if QT_VERSION < 0x040000
-  typedef QValueList<PathPropertiesMapEntry> PathPropertiesMapList;
-#else
-  typedef QList<PathPropertiesMapEntry> PathPropertiesMapList;
-#endif
-
   /** Subversion client API.
-   * 
+   *
    * Never use an object of this as global static! This will make problems with subversion
    * initialize.
    */
-  SVNQT_EXPORT class Client
+  class SVNQT_EXPORT Client
   {
   public:
+
     /**
      * Initializes the primary memory pool.
      */
@@ -117,7 +94,7 @@ namespace svn
     /**
      * @return returns the Client context
      */
-    virtual const Context *
+    virtual const ContextP
     getContext () const = 0;
 
     /**
@@ -128,7 +105,7 @@ namespace svn
      * @param context new context to use
      */
     virtual void
-    setContext (Context * context = NULL) = 0;
+    setContext (ContextP context) = 0;
 
     /**
      * get a real instance. Result must cleaned with delete.
@@ -136,7 +113,7 @@ namespace svn
      * \param subtype the wanted implementation - this moment only 0 allowed.
      * \return an instance of client or 0L if error.
      */
-     static Client*getobject(Context * context = 0,int subtype=0);
+     static Client*getobject(ContextP context,int subtype=0);
 
     /**
      * Enumerates all files/dirs at a given path.
@@ -155,14 +132,15 @@ namespace svn
      * @return vector with Status entries.
      */
     virtual StatusEntries
-    status (const QString& path,
-            const bool descend = false,
-            const bool get_all = true,
-            const bool update = false,
-            const bool no_ignore = false,
+    status (const Path& path,
+            Depth depth=DepthImmediates,
+            bool get_all = true,
+            bool update = false,
+            bool no_ignore = false,
             const Revision revision = svn::Revision::HEAD,
             bool detailed_remote = false,
-            const bool hide_externals = false) throw (ClientException) = 0;
+            bool hide_externals = false,
+            const StringArray & changelists=StringArray() ) throw (ClientException) = 0;
 
     /**
      * Returns the status of a single file in the path.
@@ -174,8 +152,8 @@ namespace svn
      * @param revision list specific revision when browsing remote, on working copies parameter will ignored
      * @return a Status with Statis.isVersioned = FALSE
      */
-    virtual Status
-    singleStatus (const QString& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException)=0;
+    virtual StatusPtr
+    singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException)=0;
 
   /**
      * Executes a revision checkout.
@@ -189,11 +167,13 @@ namespace svn
      * @exception ClientException
      */
     virtual svn_revnum_t
-    checkout (const QString& moduleName, const Path & destPath,
+    checkout (const Path& moduleName, const Path & destPath,
               const Revision & revision,
               const Revision & peg = Revision::UNDEFINED,
-              bool recurse = true,
-              bool ignore_externals=false) throw (ClientException) = 0;
+              svn::Depth depth=DepthInfinity,
+              bool ignore_externals=false,
+              bool overwrite=false
+             ) throw (ClientException) = 0;
 
     /**
      * relocate wc @a from to @a to
@@ -207,8 +187,10 @@ namespace svn
      * Sets a single file for deletion.
      * @exception ClientException
      */
-    virtual void
-    remove (const Path & path, bool force) throw (ClientException)=0;
+    virtual svn::Revision
+            remove (const Path & path, bool force,
+                    bool keep_local = true,
+                    const PropertiesMap&revProps = PropertiesMap()) throw (ClientException)=0;
 
     /**
      * Sets files for deletion.
@@ -217,28 +199,34 @@ namespace svn
      * @param force force if files are locally modified
      * @exception ClientException
      */
-    virtual void
+    virtual svn::Revision
     remove (const Targets & targets,
-            bool force) throw (ClientException) = 0;
+            bool force,
+            bool keep_local=true,
+            const PropertiesMap&revProps=PropertiesMap()) throw (ClientException) = 0;
 
     /**
      * Reverts a couple of files to a pristiner state.
      * @exception ClientException
      */
     virtual void
-    revert (const Targets & targets, bool recurse) throw (ClientException)=0;
+    revert (const Targets & targets,
+            Depth depth,
+            const StringArray&changelist=StringArray()
+           ) throw (ClientException)=0;
 
 
     /**
      * Adds a file to the repository.
      * @param path the path to add
-     * @param recurse if @a path is a folder add items recursive
+     * @param depth if @a path is a folder add items recursive depending on value if it.
      * @param force if true, do not error on already-versioned items.
      * @param no_ignore if false don't add files or directories that match ignore patterns. When build against svn 1.2 always false
+     * @param add_parents if true, go up to the next versioned folder and add all between path and this folder.
      * @exception ClientException
      */
     virtual void
-    add (const Path & path, bool recurse,bool force=false, bool no_ignore=false) throw (ClientException)=0;
+    add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_parents = true) throw (ClientException)=0;
 
     /**
      * Updates the file or directory.
@@ -246,13 +234,15 @@ namespace svn
      * @param revision the revision number to checkout.
      *                 Revision::HEAD will checkout the
      *                 latest revision.
-     * @param recurse recursively update.
-     * @param ignore_externals ignore externals (only when Subversion 1.2 or above)
+     * @param depth Depthness for operation
+     * @param ignore_externals ignore externals
+     * @param allow_unversioned will operation not fail if there are unversioned items in tree with same name.
      * @exception ClientException
      */
     virtual Revisions
     update (const Targets & path, const Revision & revision,
-            bool recurse,bool ignore_externals) throw (ClientException) = 0;
+            Depth depth,bool ignore_externals,bool allow_unversioned,
+            bool sticky_depth) throw (ClientException) = 0;
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -267,6 +257,21 @@ namespace svn
     cat (const Path & path,
           const Revision & revision,
           const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
+    /**
+     * Retrieves the contents for a specific @a revision of
+     * a @a path at @a peg_revision
+     *
+     * @param buffer Stream to store content direct
+     * @param path path of file or directory
+     * @param peg_revision revision to base the URL
+     * @param revision revision to retrieve
+     * @exception ClientException
+     */
+    virtual void
+    cat(svn::stream::SvnStream&buffer,
+            const Path & path,
+            const Revision & revision,
+            const Revision & peg_revision) throw (ClientException)=0;
     /**
      * Retrieves the contents for a specific @a revision of
      * a @a path at @a peg_revision
@@ -298,55 +303,89 @@ namespace svn
               const Path & path,
               const Revision & revisionStart,
               const Revision & revisionEnd,
-              const Revision & peg = Revision::UNDEFINED) throw (ClientException)=0;
+              const Revision & peg = Revision::UNDEFINED,
+              const DiffOptions&diffoptions = DiffOptions(),
+              bool ignore_mimetypes = false,
+              bool include_merged_revisions = false
+             ) throw (ClientException)=0;
 
     /**
      * Commits changes to the repository. This usually requires
      * authentication, see Auth.
-     * @return Returns a long representing the revision. It returns a
-     *         -1 if the revision number is invalid.
+     * @return Returns revision transferred or svn::Revision::UNDEFINED if the revision number is invalid.
      * @param targets files to commit.
      * @param message log message.
-     * @param recurse whether the operation should be done recursively.
+     * @param depth whether the operation should be done recursively.
      * @param keep_locks if false unlock items in paths
+     * @param changelist
+     * @param keep_changelist
      * @exception ClientException
      */
-    virtual svn_revnum_t
+    virtual svn::Revision
     commit (const Targets & targets,
             const QString& message,
-            bool recurse,bool keep_locks=true) throw (ClientException)=0;
+            svn::Depth depth,bool keep_locks=true,
+            const svn::StringArray&contents=svn::StringArray(),
+            const PropertiesMap&revProps=PropertiesMap(),
+            bool keep_changelist=false
+           ) throw (ClientException)=0;
 
     /**
      * Copies a versioned file with the history preserved.
      * @exception ClientException
      */
-    virtual void
+    virtual svn::Revision
     copy (const Path & srcPath,
           const Revision & srcRevision,
           const Path & destPath) throw (ClientException)=0;
+    /**
+     * Copies a versioned file with the history preserved.
+     * @since subversion 1.5 api
+     * @see svn_client_copy4
+     * @exception ClientException
+     */
+    virtual svn::Revision
+    copy (const Targets & srcPath,
+            const Revision & srcRevision,
+            const Revision & pegRevision,
+            const Path & destPath,
+            bool asChild=false,bool makeParent=false,const PropertiesMap&revProps=PropertiesMap()) throw (ClientException)=0;
 
     /**
      * Moves or renames a file.
      * @exception ClientException
      */
-    virtual void
+    virtual svn::Revision
     move (const Path & srcPath,
           const Path & destPath,
           bool force) throw (ClientException)=0;
+    /**
+     * Moves or renames a file.
+     * @exception ClientException
+     */
+    virtual svn::Revision
+            move (const Targets & srcPath,
+                  const Path & destPath,
+                  bool force,bool asChild,bool makeParent,const PropertiesMap&revProps=PropertiesMap()) throw (ClientException)=0;
 
     /**
      * Creates a directory directly in a repository or creates a
      * directory on disk and schedules it for addition. If <i>path</i>
      * is a URL then authentication is usually required, see Auth and
-     * the callback asks for a logmessage.
+     * the callback asks for a logmessage. With subversion 1.4 the target
+     * must not exist (\sa svn_client_move4)
      *
      * @param path
      * @param message log message. if it is QString::null asks when working on repository
+     * @param makeParent create parent folders if not existant (only when build with svn 1.5 or above)
      * @exception ClientException
      */
-    virtual void
+    virtual svn::Revision
     mkdir (const Path & path,
-           const QString& message) throw (ClientException)=0;
+           const QString& message,
+           bool makeParent=true,
+           const PropertiesMap&revProps=PropertiesMap()
+          ) throw (ClientException)=0;
     /**
      * Creates a directory directly in a repository or creates a
      * directory on disk and schedules it for addition. If <i>path</i>
@@ -355,11 +394,15 @@ namespace svn
      *
      * @param targets encoded pathes to create
      * @param message log message. if it is QString::null asks when working on repository
+     * @param makeParent create parent folders if not existant (only when build with svn 1.5 or above)
      * @exception ClientException
      */
-    virtual void
+    virtual svn::Revision
     mkdir (const Targets & targets,
-           const QString& message) throw (ClientException)=0;
+           const QString& message,
+           bool makeParent=true,
+           const PropertiesMap&revProps=PropertiesMap()
+          ) throw (ClientException)=0;
 
     /**
      * Recursively cleans up a local directory, finishing any
@@ -374,8 +417,7 @@ namespace svn
      * Removes the 'conflicted' state on a file.
      * @exception ClientException
      */
-    virtual void
-    resolved (const Path & path, bool recurse) throw (ClientException)=0;
+    virtual void resolve (const Path & path,Depth depth,const ConflictResult&resolution=ConflictResult()) throw (ClientException)=0;
 
     /**
      * Exports the contents of either a subversion repository into a
@@ -400,7 +442,7 @@ namespace svn
               bool overwrite=false,
               const QString&native_eol=QString::null,
               bool ignore_externals = false,
-              bool recurse = true
+              svn::Depth depth=svn::DepthInfinity
               ) throw (ClientException)=0;
 
     /**
@@ -409,9 +451,15 @@ namespace svn
      * @exception ClientException
      */
     virtual svn_revnum_t
-    doSwitch (const Path & path, const QString& url,
+    doSwitch (
+              const Path & path, const QString& url,
               const Revision & revision,
-              bool recurse) throw (ClientException)=0;
+              Depth depth,
+              const Revision & peg=Revision::UNDEFINED,
+              bool sticky_depth = true,
+              bool ignore_externals=false,
+              bool allow_unversioned=false
+             ) throw (ClientException)=0;
 
     /**
      * Import file or directory PATH into repository directory URL at
@@ -419,13 +467,17 @@ namespace svn
      * @param path path to import
      * @param url
      * @param message log message.
-     * @param recurse
+     * @param depth kind of recurse operation
+     * @param no_ignore if false, don't add items matching global ignore pattern (@since subversion 1.3)
+     * @param no_unknown_nodetype if true ignore files type not known like pipes or device files (@since subversion 1.5)
      * @exception ClientException
      */
-    virtual void
+    virtual svn::Revision
     import (const Path & path, const QString& url,
             const QString& message,
-            bool recurse) throw (ClientException)=0;
+            svn::Depth depth,
+            bool no_ignore,bool no_unknown_nodetype,
+            const PropertiesMap&revProps=PropertiesMap()) throw (ClientException)=0;
 
     /**
      * Merge changes from two paths into a new local path.
@@ -435,27 +487,56 @@ namespace svn
     merge (const Path & path1, const Revision & revision1,
            const Path & path2, const Revision & revision2,
            const Path & localPath, bool force,
-           bool recurse,
+           Depth depth,
            bool notice_ancestry=false,
-           bool dry_run=false) throw (ClientException)=0;
+           bool dry_run=false,
+           bool record_only=false,
+           const StringArray&merge_options=StringArray()
+          ) throw (ClientException)=0;
+
+    virtual void
+    merge_peg(const Path&src,
+              const RevisionRanges&ranges,
+                      const Revision&peg,
+                      const Path&targetWc,
+                      Depth depth,
+                      bool notice_ancestry=false,
+                      bool dry_run=false,
+                      bool force=false,
+                      bool record_only=false,
+                      const StringArray&merge_options=StringArray()
+                     ) throw (ClientException)=0;
+
+    virtual void
+    merge_peg(const Path&src,
+              const RevisionRange&range,
+              const Revision&peg,
+              const Path&targetWc,
+              Depth depth,
+              bool notice_ancestry=false,
+              bool dry_run=false,
+              bool force=false,
+              const StringArray&merge_options=StringArray()
+             ) throw (ClientException)=0;
 
     /**
      * Retrieve information for the given path
-     * remote or local. Only gives with subversion 1.2
-     * usefull results
+     * remote or local.
      *
      * @param path path for info
      * @param rec recursive (if dir)
      * @param rev for which revision
      * @param peg_revision peg revision
      * @return InfoEntries
-     * @since subversion 1.2
      */
     virtual InfoEntries
-    info(const QString &path,
-          bool rec,
+    info (const Path &path,
+          Depth depth,
           const Revision & rev,
-          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
+          const Revision & peg_revision=svn_opt_revision_unspecified,
+          const StringArray&changelists=StringArray()
+         ) throw (ClientException)=0;
+
     /**
      * Retrieve log information for the given path
      * Loads the log messages result set. The first
@@ -469,14 +550,19 @@ namespace svn
      * @param revisionEnd
      * @param discoverChangedPaths
      * @param strictNodeHistory
-     * @param limit (ignored when subversion 1.1 API)
+     * @param limit the maximum log entries count.
      * @return a vector with log entries
      */
-    virtual const LogEntries *
-    log (const QString& path, const Revision & revisionStart,
+    virtual LogEntriesPtr
+    log (const Path& path,
+         const Revision & revisionStart,
          const Revision & revisionEnd,
+         const Revision & revisionPeg,
          bool discoverChangedPaths=false,
-         bool strictNodeHistory=true,int limit = 0) throw (ClientException)=0;
+         bool strictNodeHistory=true,int limit = 0,
+         bool include_merged_revisions = false,
+         const StringArray&revprops=StringArray()
+        ) throw (ClientException)=0;
 
     /**
      * Retrieve log information for the given path
@@ -486,7 +572,7 @@ namespace svn
      * You can use the constants Revision::START and
      * Revision::HEAD
      *
-     * @param path
+     * @param path Path to make a log for
      * @param revisionStart
      * @param revisionEnd
      * @param target the logmap where to store the entries
@@ -496,11 +582,15 @@ namespace svn
      * @return true if success
      */
     virtual bool
-    log (const QString& path, const Revision & revisionStart,
+    log (const Path& path, const Revision & revisionStart,
          const Revision & revisionEnd,
          LogEntriesMap&target,
+         const Revision & revisionPeg=Revision::UNDEFINED,
          bool discoverChangedPaths=false,
-         bool strictNodeHistory=true,int limit = 0) throw (ClientException)=0;
+         bool strictNodeHistory=true,int limit = 0,
+         bool include_merged_revisions = false,
+         const StringArray&revprops=StringArray()
+        ) throw (ClientException)=0;
 
     /**
      * Produce diff output which describes the delta between
@@ -521,14 +611,28 @@ namespace svn
      * relatedness.
      * @param noDiffDeleted if true, no diff output will be generated on deleted files.
      * @param ignore_contenttype if true generate diff even the items are marked as binaries
+     * @param extra extra options for diff ("-b", "-w","--ignore-eol-style")
      * @return delta between the files
      * @exception ClientException
      */
     virtual QByteArray
-    diff (const Path & tmpPath, const Path & path,
-          const Revision & revision1, const Revision & revision2,
-          const bool recurse, const bool ignoreAncestry,
-          const bool noDiffDeleted,const bool ignore_contenttype) throw (ClientException)=0;
+            diff_peg(const Path & tmpPath, const Path & path,const Path&relativeTo,
+          const Revision & revision1, const Revision & revision2, const Revision& peg_revision,
+          Depth depth, bool ignoreAncestry,
+          bool noDiffDeleted,bool ignore_contenttype,
+          const StringArray&extra,
+          const StringArray&changelists
+            ) throw (ClientException)=0;
+
+    /**
+     * Same as other diff but extra options always set to empty list.
+     */
+    virtual QByteArray
+            diff_peg (const Path & tmpPath, const Path & path,const Path&relativeTo,
+                  const Revision & revision1, const Revision & revision2, const Revision& peg_revision,
+                  Depth depth, bool ignoreAncestry,
+                  bool noDiffDeleted,bool ignore_contenttype) throw (ClientException)=0;
+
     /**
      * Produce diff output which describes the delta between
      * @a path1/@a revision1 and @a path2/@a revision2. @a path2
@@ -549,14 +653,27 @@ namespace svn
      * relatedness.
      * @param noDiffDeleted if true, no diff output will be generated on deleted files.
      * @param ignore_contenttype if true generate diff even the items are marked as binaries
+     * @param extra extra options for diff ("-b", "-w","--ignore-eol-style")
      * @return delta between the files
      * @exception ClientException
      */
     virtual QByteArray
-    diff (const Path & tmpPath, const Path & path1,const Path & path2,
+            diff (const Path & tmpPath, const Path & path1,const Path & path2,const Path&relativeTo,
           const Revision & revision1, const Revision & revision2,
-          const bool recurse, const bool ignoreAncestry,
-          const bool noDiffDeleted,const bool ignore_contenttype) throw (ClientException)=0;
+          Depth depth, bool ignoreAncestry,
+          bool noDiffDeleted,bool ignore_contenttype,
+          const StringArray&extra,
+          const StringArray&changelists
+         ) throw (ClientException)=0;
+
+    /**
+     * Same as other diff but extra options and changelists always set to empty list.
+     */
+    virtual QByteArray
+            diff (const Path & tmpPath, const Path & path1,const Path & path2,const Path&relativeTo,
+                  const Revision & revision1, const Revision & revision2,
+                  Depth depth, bool ignoreAncestry,
+                  bool noDiffDeleted,bool ignore_contenttype) throw (ClientException)=0;
 
     /**
      * lists entries in @a pathOrUrl no matter whether local or
@@ -567,16 +684,17 @@ namespace svn
      * @param pathOrUrl
      * @param revision
      * @param peg at wich revision path exists
-     * @param recurse
+     * @param depth @sa depth
      * @param retrieve_locks check for REPOSITORY locks while listing.
      * @return a vector of directory entries, each with
-     *         a relative path (only filename)
+     *         a relative path (only filename). In subversion >= 1.4 an entry without a name is returned, too. This
+     *         is the searched directory (done in subversion itself)
      */
     virtual DirEntries
-    list (const QString& pathOrUrl,
+    list (const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
-          bool recurse,bool retrieve_locks) throw (ClientException)=0;
+          svn::Depth depth,bool retrieve_locks) throw (ClientException)=0;
 
     /**
      * lists properties in @a path no matter whether local or
@@ -588,11 +706,13 @@ namespace svn
      * @param recurse
      * @return PropertiesList
      */
-    virtual PathPropertiesMapList
+    virtual PathPropertiesMapListPtr
     proplist(const Path &path,
              const Revision &revision,
              const Revision &peg,
-             bool recurse=false)=0;
+             Depth depth=DepthEmpty,
+             const StringArray&changelists=StringArray()
+            )=0;
 
     /**
      * lists one property in @a path no matter whether local or
@@ -603,14 +723,15 @@ namespace svn
      * @param revision
      * @param peg most case should set to @a revision
      * @param recurse
-     * @return PathPropertiesMapList
+     * @return PathPropertiesMapList and revision where the properties are taken from (svn 1.5) or undefined revision (prior 1.5)
      */
-    virtual PathPropertiesMapList
+    virtual QPair<QLONG,PathPropertiesMapList>
     propget(const QString& propName,
             const Path &path,
             const Revision &revision,
             const Revision &peg,
-            bool recurse=false) = 0;
+            Depth depth = svn::DepthEmpty,
+            const StringArray&changelists=StringArray()) = 0;
 
     /**
      * set property in @a path no matter whether local or
@@ -628,9 +749,12 @@ namespace svn
     propset(const QString& propName,
             const QString& propValue,
             const Path &path,
-            const Revision &revision,
-            bool recurse=false,
-            bool skip_checks=false) = 0;
+            Depth depth=DepthEmpty,
+            bool skip_checks=false,
+            const Revision&base_revision=Revision::UNDEFINED,
+            const StringArray&changelists=StringArray(),
+            const PropertiesMap&revProps=PropertiesMap()
+           ) = 0;
 
     /**
      * delete property in @a path no matter whether local or
@@ -644,8 +768,10 @@ namespace svn
     virtual void
     propdel(const QString& propName,
             const Path &path,
-            const Revision &revision,
-            bool recurse=false)=0;
+            Depth depth=DepthEmpty,
+            bool skip_check=false,
+            const Revision&base_revision=Revision::UNDEFINED,
+            const StringArray&changelists=StringArray())=0;
 
 
     /**
@@ -656,7 +782,7 @@ namespace svn
      * @param revision
      * @return PropertiesList
      */
-    virtual QPair<svn_revnum_t,PropertiesMap>
+    virtual QPair<QLONG,PropertiesMap>
     revproplist(const Path &path,
                 const Revision &revision)=0;
 
@@ -669,7 +795,7 @@ namespace svn
      * @param revision
      * @return PropertiesList
      */
-    virtual QPair<svn_revnum_t,QString>
+    virtual QPair<QLONG,QString>
     revpropget(const QString& propName,
                const Path &path,
                const Revision &revision)=0;
@@ -685,7 +811,7 @@ namespace svn
      * @param force
      * @return Revision
      */
-    virtual svn_revnum_t
+    virtual QLONG
     revpropset(const QString& propName,
                const QString& propValue,
                const Path &path,
@@ -702,7 +828,7 @@ namespace svn
      * @param force
      * @return Revision
      */
-    virtual svn_revnum_t
+    virtual QLONG
     revpropdel(const QString& propName,
                const Path &path,
                const Revision &revision,
